@@ -30,12 +30,12 @@
 #include <tqstringlist.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <tdelocale.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
 #include <ktrader.h>
 #include <klibloader.h>
 
@@ -287,7 +287,7 @@ const TQString& KMFGenericDoc::compile() {
 void KMFGenericDoc::parseDocument( const KURL& url, TQStringList& errors ) {
 // 	kdDebug() << "KMFDoc* KMFGenericDoc::parseDocument( const KURL& )" << endl;
 	TQString xmlfile;
-	if ( ! KIO::NetAccess::download( url, xmlfile, KApplication::kApplication()->mainWidget() ) ) {
+	if ( ! TDEIO::NetAccess::download( url, xmlfile, TDEApplication::kApplication()->mainWidget() ) ) {
 		clear();
 		m_url.setFileName( i18n( "Untitled" ) );
 		return;
@@ -318,11 +318,11 @@ void KMFGenericDoc::parseDocument( const KURL& url, TQStringList& errors ) {
 		m_url = url;
 		// setUrl( url );
 		emit documentChanged();
-		KIO::NetAccess::removeTempFile( xmlfile );
+		TDEIO::NetAccess::removeTempFile( xmlfile );
 		return;
 	//	return this;
 	}
-	KIO::NetAccess::removeTempFile( xmlfile );
+	TDEIO::NetAccess::removeTempFile( xmlfile );
 //	return this;
 }
 
